@@ -275,31 +275,15 @@ setMethod("solve", signature(a = "Matrix", b = "ANY"),
 setMethod("solve", signature(a = "ANY", b = "Matrix"),
 	  function(a, b, ...) .bail.out.2("solve", class(a), class(b)))
 
-if(getRversion() < "2.10.0" || R.version$`svn rev` < 49944) {
-    ## for now: still carry  'size' and 'LINPACK'
-setMethod("chol2inv", signature(x = "denseMatrix"),
-	  function (x, size, LINPACK)
-	  chol2inv(as(as(x, "dMatrix"), "dtrMatrix"), size, LINPACK))
-setMethod("chol2inv", signature(x = "sparseMatrix"),
-	  function (x, size, LINPACK) {
-	      if (!missing(size) || !missing(LINPACK))
-		  warning("Arguments size and LINPACK are ignored for chol2inv\n\tmethods in the Matrix package")
-	      ## for now:
-	      tcrossprod(solve(as(x,"triangularMatrix")))
-	  })
-
-} else {## chol2inv() has implicit generic in newer versions of R
-
 setMethod("chol2inv", signature(x = "denseMatrix"),
 	  function (x, ...) chol2inv(as(as(x, "dMatrix"), "dtrMatrix"), ...))
 setMethod("chol2inv", signature(x = "sparseMatrix"),
 	  function (x, ...) {
 	      if(length(list(...)))
-		  warning("arguments in", deparse(list(...)), "are disregarded")
+		  warning("arguments in ",deparse(list(...))," are disregarded")
 	      ## for now:
 	      tcrossprod(solve(as(x,"triangularMatrix")))
 	  })
-}# end {if}
 
 ## There are special sparse methods; this is a "fall back":
 setMethod("kronecker", signature(X = "Matrix", Y = "ANY",
